=== added file 'docs/ipv6_data_type.rst'
--- docs/ipv6_data_type.rst	1970-01-01 00:00:00 +0000
+++ docs/ipv6_data_type.rst	2011-08-16 11:47:29 +0000
@@ -0,0 +1,28 @@
+IPV6 Data Type
+==============
+
+The data type IPV6 stores Internet Protocol version(IPv) 4 & 6 addresses. 
+
+This data type is a 128-bit quantity that is generated by an algorithm designed to make it very unlikely that the same data type will be generated by anyone else in the world using the same algorithm. 
+
+IPv6 address are written in preferred form as x:x:x:x:x:x:x:x, where the 'x's are the hexadecimal values of the eight 16-bit pieces of the address separated by colons. Leading zeros in a group are allowed to be dropped, upper and lower case are equivalent. For example:
+
+	 1080:0:0:0:8:800:200C:417A  a unicast address
+         FF01:0:0:0:0:0:0:101        a multicast address
+         0:0:0:0:0:0:0:1             the loopback address
+         0:0:0:0:0:0:0:0             the unspecified addresses
+
+may be represented as:
+
+         1080::8:800:200C:417A       a unicast address
+         FF01::101                   a multicast address
+         ::1                         the loopback address
+         ::                          the unspecified addresses
+
+The IPV6 data type support to store IPv4 address in specific format. 
+For example:
+
+::192.168.1.10
+
+IPV6 are documented as part of Standard Track :rfc:'2373'.
+

=== modified file 'drizzled/common.h'
--- drizzled/common.h	2011-05-21 00:29:07 +0000
+++ drizzled/common.h	2011-08-16 11:47:29 +0000
@@ -187,9 +187,10 @@
                         DRIZZLE_TYPE_TIME,
                         DRIZZLE_TYPE_BOOLEAN,
                         DRIZZLE_TYPE_UUID,
-                        DRIZZLE_TYPE_MICROTIME
+                        DRIZZLE_TYPE_MICROTIME,
+                        DRIZZLE_TYPE_IPV6
 };
-const int enum_field_types_size= DRIZZLE_TYPE_MICROTIME + 1;
+const int enum_field_types_size= DRIZZLE_TYPE_IPV6 + 1;
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2011-08-04 08:13:04 +0000
+++ drizzled/create_field.cc	2011-08-16 11:47:29 +0000
@@ -45,6 +45,7 @@
 #include <drizzled/field/datetime.h>
 #include <drizzled/field/varstring.h>
 #include <drizzled/field/uuid.h>
+#include <drizzled/field/ipv6.h>
 #include <drizzled/temporal.h>
 #include <drizzled/item/string.h>
 #include <drizzled/table.h>
@@ -290,6 +291,9 @@
     case DRIZZLE_TYPE_UUID:
       length= field::Uuid::max_string_length();
       break;
+    case DRIZZLE_TYPE_IPV6:
+      length= field::IPv6::max_string_length();
+      break;
     case DRIZZLE_TYPE_BOOLEAN:
       length= field::Boolean::max_string_length();
       break;

=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2011-05-21 00:29:07 +0000
+++ drizzled/display.cc	2011-08-16 11:47:29 +0000
@@ -56,6 +56,7 @@
 static const std::string DRIZZLE_TYPE_BLOB("DRIZZLE_TYPE_BLOB"); 
 static const std::string DRIZZLE_TYPE_UUID("DRIZZLE_TYPE_UUID"); 
 static const std::string DRIZZLE_TYPE_BOOLEAN("DRIZZLE_TYPE_BOOLEAN"); 
+static const std::string DRIZZLE_TYPE_IPV6("DRIZZLE_TYPE_IPV6"); 
 
 static const std::string FIELD_ITEM("FIELD_ITEM");
 static const std::string FUNC_ITEM("FUNC_ITEM");
@@ -279,6 +280,8 @@
     return DRIZZLE_TYPE_UUID;
   case drizzled::DRIZZLE_TYPE_BOOLEAN : 
     return DRIZZLE_TYPE_BOOLEAN;
+  case drizzled::DRIZZLE_TYPE_IPV6 : 
+    return DRIZZLE_TYPE_IPV6;
   }
 
   assert(0);

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2011-03-24 00:03:05 +0000
+++ drizzled/error.cc	2011-08-16 11:47:29 +0000
@@ -598,6 +598,9 @@
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_VALUE, N_("Received an invalid UUID value"));
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_TIME, N_("The UUID was not created with a valid time"));
 
+  // For IPV6 type
+  ADD_ERROR_MESSAGE(ER_INVALID_IPV6_VALUE, N_("Received an invalid IPV6 value"));
+
   // For BOOL type
   ADD_ERROR_MESSAGE(ER_INVALID_BOOLEAN_VALUE, N_("Received an invalid BOOLEAN value '%s'."));
   ADD_ERROR_MESSAGE(ER_INVALID_CAST_TO_BOOLEAN, N_("Invalid cast to BOOLEAN: '%s'."));

=== modified file 'drizzled/error_t.h'
--- drizzled/error_t.h	2011-03-14 05:40:28 +0000
+++ drizzled/error_t.h	2011-08-16 11:47:29 +0000
@@ -850,6 +850,7 @@
   ER_INVALID_CAST_TO_UNSIGNED,
   ER_INVALID_UUID_TIME,
   ER_INVALID_UUID_VALUE,
+  ER_INVALID_IPV6_VALUE,
   ER_SQL_KEYWORD,
   ER_TABLE_DROP,
   ER_TABLE_DROP_ERROR_OCCURRED,

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2011-08-05 09:22:50 +0000
+++ drizzled/field.cc	2011-08-16 11:47:29 +0000
@@ -48,6 +48,7 @@
 #include <drizzled/field/microtime.h>
 #include <drizzled/field/varstring.h>
 #include <drizzled/field/uuid.h>
+#include <drizzled/field/ipv6.h>
 #include <drizzled/time_functions.h>
 #include <drizzled/internal/m_string.h>
 #include <drizzled/table.h>
@@ -99,6 +100,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DOUBLE -> */
   {
@@ -132,6 +135,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_NULL -> */
   {
@@ -165,6 +170,8 @@
     DRIZZLE_TYPE_UUID,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_MICROTIME,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_TIMESTAMP -> */
   {
@@ -198,6 +205,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_LONGLONG -> */
   {
@@ -230,6 +239,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DATETIME -> */
   {
@@ -263,6 +274,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DATE -> */
   {
@@ -296,6 +309,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_VARCHAR -> */
   {
@@ -329,6 +344,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DECIMAL -> */
   {
@@ -362,6 +379,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_ENUM -> */
   {
@@ -395,6 +414,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
    },
   /* DRIZZLE_TYPE_BLOB -> */
   {
@@ -428,6 +449,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_TIME -> */
   {
@@ -461,6 +484,8 @@
     DRIZZLE_TYPE_UUID,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_BOOLEAN -> */
   {
@@ -494,6 +519,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_UUID -> */
   {
@@ -527,6 +554,8 @@
     DRIZZLE_TYPE_UUID,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_MICROTIME -> */
   {
@@ -560,6 +589,43 @@
     DRIZZLE_TYPE_UUID,
     //DRIZZLE_TYPE_MICROTIME
     DRIZZLE_TYPE_MICROTIME,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
+  },
+  /* DRIZZLE_TYPE_IPV6 -> */
+  {
+    //DRIZZLE_TYPE_LONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DOUBLE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_NULL
+    DRIZZLE_TYPE_IPV6,
+    //DRIZZLE_TYPE_TIMESTAMP
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_LONGLONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATETIME
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DECIMAL
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR,
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_BLOB
+    DRIZZLE_TYPE_BLOB,
+    //DRIZZLE_TYPE_TIME
+    DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_UUID
+    DRIZZLE_TYPE_UUID,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_MICROTIME,
+    //DRIZZLE_TYPE_IPV6
+    DRIZZLE_TYPE_VARCHAR,
   },
 };
 
@@ -595,6 +661,8 @@
   STRING_RESULT,
   //DRIZZLE_TYPE_MICROTIME
   STRING_RESULT,
+  //DRIZZLE_TYPE_IPV6
+  STRING_RESULT,
 };
 
 bool test_if_important_data(const charset_info_st * const cs, 
@@ -1111,6 +1179,7 @@
   case DRIZZLE_TYPE_MICROTIME: return field::Microtime::max_string_length();
   case DRIZZLE_TYPE_TIMESTAMP: return field::Epoch::max_string_length();
   case DRIZZLE_TYPE_BOOLEAN: return field::Boolean::max_string_length();
+  case DRIZZLE_TYPE_IPV6: return field::IPv6::max_string_length();
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_LONG: return 4;

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2011-08-03 10:04:55 +0000
+++ drizzled/field.h	2011-08-16 11:47:29 +0000
@@ -762,6 +762,7 @@
   case DRIZZLE_TYPE_LONGLONG:
   case DRIZZLE_TYPE_NULL:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_VARCHAR:
     return false;
   }

=== added file 'drizzled/field/ipv6.cc'
--- drizzled/field/ipv6.cc	1970-01-01 00:00:00 +0000
+++ drizzled/field/ipv6.cc	2011-08-16 11:47:29 +0000
@@ -0,0 +1,136 @@
+/*
+  Original copyright header listed below. This comes via rsync.
+  Any additional changes are provided via the same license as the original.
+
+  Copyright (C) 2011 Muhammad Umair
+
+*/
+/*
+ * Copyright (C) 1996-2001  Internet Software Consortium.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+ * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+ * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+
+#include "config.h"
+
+#include <algorithm>
+
+#include <drizzled/field/ipv6.h>
+
+#include <drizzled/error.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/session.h>
+#include <drizzled/table.h>
+
+namespace drizzled
+{
+namespace field
+{
+
+IPv6::IPv6(unsigned char *ptr_arg,
+           uint32_t len_arg,
+           unsigned char *null_ptr_arg,
+           unsigned char null_bit_arg,
+           const char *field_name_arg) :
+  Field(ptr_arg, len_arg,
+        null_ptr_arg,
+        null_bit_arg,
+        Field::NONE,
+        field_name_arg)
+{
+}
+
+int IPv6::cmp(const unsigned char *a, const unsigned char *b)
+{
+  return memcmp(a, b, max_string_length());
+}
+  
+int IPv6::store(const char *from, uint32_t, const charset_info_st * const )
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  type::IPv6 ptr_address;
+
+  if (not ptr_address.inet_pton(from))
+  {
+    my_error(ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+    return 1;
+  }
+
+ ptr_address.store_object(ptr);
+
+  return 0;
+}
+
+int IPv6::store(int64_t , bool )
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  my_error(ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+  return 1;
+}
+
+int IPv6::store_decimal(const drizzled::type::Decimal*)
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  my_error(ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+  return 1;
+}
+
+void IPv6::sql_type(String &res) const
+{
+  res.set_ascii(STRING_WITH_LEN("ipv6"));
+}
+
+double IPv6::val_real() const
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  my_error(ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+  return 0;
+}
+
+int64_t IPv6::val_int() const
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  my_error(ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+  return 0;
+}
+
+String *IPv6::val_str(String *val_buffer, String *) const
+{
+  const charset_info_st * const cs= &my_charset_bin;
+  uint32_t mlength= (type::IPv6::IPV6_BUFFER_LENGTH)  * cs->mbmaxlen;  
+  type::IPv6 ptr_address;
+
+  val_buffer->alloc(mlength);
+  char *buffer=(char*) val_buffer->ptr();
+ 
+  ASSERT_COLUMN_MARKED_FOR_READ;
+
+  ptr_address.restore_object(ptr);  
+  ptr_address.inet_ntop(buffer);
+
+  val_buffer->length(type::IPv6::IPV6_DISPLAY_LENGTH);
+
+  return val_buffer;
+}
+
+void IPv6::sort_string(unsigned char *to, uint32_t length_arg)
+{
+  assert(length_arg == type::IPv6::LENGTH);
+  memcpy(to, ptr, length_arg);
+}
+
+} /* namespace field */
+} /* namespace drizzled */
+

=== added file 'drizzled/field/ipv6.h'
--- drizzled/field/ipv6.h	1970-01-01 00:00:00 +0000
+++ drizzled/field/ipv6.h	2011-08-16 11:47:29 +0000
@@ -0,0 +1,80 @@
+/*
+  Original copyright header listed below. This comes via rsync.
+  Any additional changes are provided via the same license as the original.
+
+  Copyright (C) 2011 Muhammad Umair
+
+*/
+/*
+ * Copyright (C) 1996-2001  Internet Software Consortium.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+ * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+ * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#pragma once
+
+#include <drizzled/field.h>
+#include <string>
+
+#include <drizzled/type/ipv6.h>
+
+namespace drizzled
+{
+namespace field
+{
+
+class IPv6:public Field {
+  const charset_info_st *field_charset;
+
+public:
+  IPv6(unsigned char *ptr_arg,
+            uint32_t len_arg,
+            unsigned char *null_ptr_arg,
+            unsigned char null_bit_arg,
+            const char *field_name_arg);
+
+  enum_field_types type() const { return DRIZZLE_TYPE_IPV6; }
+  enum ha_base_keytype key_type() const { return HA_KEYTYPE_BINARY; }
+  bool zero_pack() const { return 0; }
+  int  reset(void) { memset(ptr, 0, type::IPv6::LENGTH); return 0; }
+  uint32_t pack_length() const { return type::IPv6::LENGTH; }
+  uint32_t key_length() const { return type::IPv6::LENGTH; }
+
+  int  store(const char *to,uint32_t length, const charset_info_st * const charset);
+  int  store(int64_t nr, bool unsigned_val);
+  double val_real() const;
+  int64_t val_int() const;
+  String *val_str(String*,String *) const;
+  void sql_type(drizzled::String&)  const;
+  int store_decimal(const drizzled::type::Decimal*);
+
+  Item_result result_type () const { return STRING_RESULT; }
+  int cmp(const unsigned char*, const unsigned char*);
+  void sort_string(unsigned char*, uint32_t);
+  uint32_t max_display_length() { return type::IPv6::IPV6_DISPLAY_LENGTH; }
+
+  int  store(double ) { return 0; }
+  inline String *val_str(String *str) { return val_str(str, str); }
+  uint32_t size_of() const { return sizeof(*this); }
+
+  static size_t max_string_length()
+  {
+    return type::IPv6::LENGTH;
+  }
+};
+
+} /* namespace field */
+} /* namespace drizzled */
+
+

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2011-08-12 16:41:20 +0000
+++ drizzled/include.am	2011-08-16 11:47:29 +0000
@@ -111,6 +111,7 @@
 			      drizzled/field/str.h \
 			      drizzled/field/time.h \
 			      drizzled/field/uuid.h \
+			      drizzled/field/ipv6.h \
 			      drizzled/field/varstring.h \
 			      drizzled/field_iterator.h \
 			      drizzled/file_exchange.h \
@@ -506,6 +507,7 @@
 			      drizzled/type/decimal.h \
 			      drizzled/type/time.h \
 			      drizzled/type/uuid.h \
+			      drizzled/type/ipv6.h \
 			      drizzled/typelib.h \
 			      drizzled/unique.h \
 			      drizzled/unireg.h \
@@ -586,6 +588,7 @@
 			   drizzled/field/str.cc \
 			   drizzled/field/time.cc \
 			   drizzled/field/uuid.cc \
+			   drizzled/field/ipv6.cc \
 			   drizzled/field/varstring.cc \
 			   drizzled/field_conv.cc \
 			   drizzled/field_iterator.cc \

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2011-08-08 16:24:13 +0000
+++ drizzled/item.cc	2011-08-16 11:47:29 +0000
@@ -1178,6 +1178,7 @@
     break;
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_VARCHAR:
     return make_string_field(table);
@@ -1326,6 +1327,7 @@
   case DRIZZLE_TYPE_VARCHAR:
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_DECIMAL:
     {
       if (String* res=val_str(buffer))

=== modified file 'drizzled/item/type_holder.cc'
--- drizzled/item/type_holder.cc	2011-06-22 20:05:58 +0000
+++ drizzled/item/type_holder.cc	2011-08-16 11:47:29 +0000
@@ -209,6 +209,7 @@
   case DRIZZLE_TYPE_TIME:
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_TIMESTAMP:
   case DRIZZLE_TYPE_DATETIME:

=== modified file 'drizzled/message.cc'
--- drizzled/message.cc	2011-07-14 22:12:02 +0000
+++ drizzled/message.cc	2011-08-16 11:47:29 +0000
@@ -51,6 +51,7 @@
 static const std::string TIME("TIME");
 static const std::string UUID("UUID");
 static const std::string BOOLEAN("BOOLEAN");
+static const std::string IPV6("IPV6");
 
 static const std::string UNDEFINED("UNDEFINED");
 static const std::string RESTRICT("RESTRICT");
@@ -109,6 +110,7 @@
   case message::Table::Field::TIME:
   case message::Table::Field::UUID:
   case message::Table::Field::BOOLEAN:
+  case message::Table::Field::IPV6:
     break;
   }
 
@@ -147,6 +149,8 @@
     return UUID;
   case message::Table::Field::BOOLEAN:
     return BOOLEAN;
+  case message::Table::Field::IPV6:
+    return IPV6;
   }
 
   abort();
@@ -182,6 +186,8 @@
     return UUID;
   case message::Table::Field::BOOLEAN:
     return BOOLEAN;
+  case message::Table::Field::IPV6:
+    return IPV6;
   }
 
   abort();

=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2011-04-28 18:07:05 +0000
+++ drizzled/message/statement_transform.cc	2011-08-16 11:47:29 +0000
@@ -1425,6 +1425,9 @@
   case Table::Field::UUID:
     destination.append(" UUID");
     break;
+  case Table::Field::IPV6:
+    destination.append(" IPV6");
+    break;
   case Table::Field::BOOLEAN:
     destination.append(" BOOLEAN");
     break;
@@ -1606,6 +1609,8 @@
     return Table::Field::UUID;
   case DRIZZLE_TYPE_BOOLEAN:
     return Table::Field::BOOLEAN;
+  case DRIZZLE_TYPE_IPV6:
+    return Table::Field::IPV6;
   }
 
   assert(false);

=== modified file 'drizzled/message/table.proto'
--- drizzled/message/table.proto	2011-04-04 21:37:55 +0000
+++ drizzled/message/table.proto	2011-08-16 11:47:29 +0000
@@ -82,6 +82,7 @@
       UUID = 11;
       TIME = 12;
       BOOLEAN = 13;
+      IPV6 = 14;
     }
 
     message FieldOptions {

=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-08-05 09:43:18 +0000
+++ drizzled/parser.cc	2011-08-16 11:47:29 +0000
@@ -594,6 +594,14 @@
   return DRIZZLE_TYPE_UUID;
 }
 
+drizzled::enum_field_types buildIPv6Column(LEX *lex)
+{
+  if (lex->field())
+    lex->field()->set_type(message::Table::Field::IPV6);
+
+  return DRIZZLE_TYPE_IPV6;
+}
+
 drizzled::enum_field_types buildDoubleColumn(LEX *lex)
 {
   if (lex->field())

=== modified file 'drizzled/parser.h'
--- drizzled/parser.h	2011-08-03 10:04:55 +0000
+++ drizzled/parser.h	2011-08-16 11:47:29 +0000
@@ -147,6 +147,7 @@
 drizzled::enum_field_types buildBlobColumn(LEX *lex);
 drizzled::enum_field_types buildBooleanColumn(LEX *lex);
 drizzled::enum_field_types buildUuidColumn(LEX *lex);
+drizzled::enum_field_types buildIPv6Column(LEX *lex);
 drizzled::enum_field_types buildDoubleColumn(LEX *lex);
 drizzled::enum_field_types buildTimestampColumn(LEX *lex, const char *length);
 drizzled::enum_field_types buildDecimalColumn(LEX *lex);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-08-08 12:51:19 +0000
+++ drizzled/sql_table.cc	2011-08-16 11:47:29 +0000
@@ -503,6 +503,7 @@
   case DRIZZLE_TYPE_NULL:
   case DRIZZLE_TYPE_TIME:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_VARCHAR:
     break;
   }

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-08-08 17:05:09 +0000
+++ drizzled/sql_yacc.yy	2011-08-16 11:47:29 +0000
@@ -365,6 +365,7 @@
 %token  IS                            /* SQL-2003-R */
 %token  ISOLATION                     /* SQL-2003-R */
 %token  ITERATE_SYM
+%token  IPV6_SYM
 %token  JOIN_SYM                      /* SQL-2003-R */
 %token  KEYS
 %token  KEY_BLOCK_SIZE
@@ -1335,6 +1336,10 @@
           {
             $$= parser::buildUuidColumn(&Lex);
           }
+        | IPV6_SYM opt_attribute
+          {
+            $$= parser::buildIPv6Column(&Lex);
+          }
         | BOOLEAN_SYM opt_attribute_boolean
           {
             $$= parser::buildBooleanColumn(&Lex);
@@ -3047,6 +3052,14 @@
             }
             Lex.setCacheable(false);
 	  }
+        | IPV6_SYM '(' ')'
+          {
+            if (! ($$= parser::reserved_keyword_function(YYSession, "ipv6", NULL)))
+            {
+              DRIZZLE_YYABORT;
+            }
+            Lex.setCacheable(false);
+	  }
         | WAIT_SYM '(' expr ',' expr ')'
           {
             List<Item> *args= new (YYSession->mem_root) List<Item>;
@@ -5296,6 +5309,7 @@
         | IMPORT                   {}
         | INDEXES                  {}
         | ISOLATION                {}
+        | IPV6_SYM                 {}
         | KEY_BLOCK_SIZE           {}
         | LAST_SYM                 {}
         | LEVEL_SYM                {}

=== modified file 'drizzled/symbol_hash.gperf'
--- drizzled/symbol_hash.gperf	2011-07-01 18:59:28 +0000
+++ drizzled/symbol_hash.gperf	2011-08-16 11:47:29 +0000
@@ -209,6 +209,7 @@
 IS, IS
 ISOLATION, ISOLATION
 ITERATE, ITERATE_SYM
+IPV6, IPV6_SYM
 JOIN, JOIN_SYM
 KEY, KEY_SYM
 KEYS, KEYS

=== modified file 'drizzled/table/instance/base.cc'
--- drizzled/table/instance/base.cc	2011-08-08 16:21:01 +0000
+++ drizzled/table/instance/base.cc	2011-08-16 11:47:29 +0000
@@ -80,6 +80,7 @@
 #include <drizzled/field/microtime.h>
 #include <drizzled/field/varstring.h>
 #include <drizzled/field/uuid.h>
+#include <drizzled/field/ipv6.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/definition/cache.h>
 #include <drizzled/typelib.h>
@@ -132,6 +133,9 @@
   case message::Table::Field::UUID:
     return  DRIZZLE_TYPE_UUID;
 
+  case message::Table::Field::IPV6:
+    return  DRIZZLE_TYPE_IPV6;
+
   case message::Table::Field::BOOLEAN:
     return DRIZZLE_TYPE_BOOLEAN;
 
@@ -185,6 +189,7 @@
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_BOOLEAN:
     default_item= new Item_string(default_value->c_str(),
@@ -1162,6 +1167,9 @@
     case DRIZZLE_TYPE_UUID:
       field_length= field::Uuid::max_string_length();
       break;
+    case DRIZZLE_TYPE_IPV6:
+      field_length= field::IPv6::max_string_length();
+      break;
     case DRIZZLE_TYPE_BOOLEAN:
       field_length= field::Boolean::max_string_length();
       break;
@@ -1221,6 +1229,7 @@
     case DRIZZLE_TYPE_LONGLONG:
     case DRIZZLE_TYPE_NULL:
     case DRIZZLE_TYPE_UUID:
+    case DRIZZLE_TYPE_IPV6:
     case DRIZZLE_TYPE_BOOLEAN:
       break;
     }
@@ -1929,6 +1938,12 @@
                                        null_pos,
                                        null_bit,
                                        field_name);
+  case DRIZZLE_TYPE_IPV6:
+    return new (&mem_root) field::IPv6(ptr,
+                                       field_length,
+                                       null_pos,
+                                       null_bit,
+                                       field_name);
   case DRIZZLE_TYPE_BOOLEAN:
     return new (&mem_root) field::Boolean(ptr,
                                           field_length,

=== modified file 'drizzled/table_proto.cc'
--- drizzled/table_proto.cc	2011-07-24 16:27:12 +0000
+++ drizzled/table_proto.cc	2011-08-16 11:47:29 +0000
@@ -135,6 +135,7 @@
     case message::Table::Field::DATE:
     case message::Table::Field::DATETIME:
     case message::Table::Field::UUID:
+    case message::Table::Field::IPV6:
     case message::Table::Field::TIME:
     case message::Table::Field::BOOLEAN:
       break;

=== added file 'drizzled/type/ipv6.h'
--- drizzled/type/ipv6.h	1970-01-01 00:00:00 +0000
+++ drizzled/type/ipv6.h	2011-08-16 11:47:29 +0000
@@ -0,0 +1,454 @@
+/*
+  Original copyright header listed below. This comes via rsync.
+  Any additional changes are provided via the same license as the original.
+
+  Copyright (C) 2011 Muhammad Umair
+
+*/
+/*
+ * Copyright (C) 1996-2001  Internet Software Consortium.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+ * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+ * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#pragma once
+
+#include<cstdio>
+#include<cstring>
+#include <iostream>
+
+namespace drizzled
+{
+namespace type
+{
+
+class IPv6 {
+
+    struct ipv6_ds
+    {
+    	unsigned short ip6[8];
+    }str;
+    
+    //Function to store the IPv4 address in IPv6 Data Structure
+    int ipv4_inet_pton(const char *src)
+    {
+
+	    char *ptr_src ;
+
+	    char ipv4_map_ipv6[20],ipv4[16], octet_1[5],octet_2[5],concat_octets[20];
+	    int octet[4],octet_index = 0;
+
+	    memset(ipv4_map_ipv6, NULL, sizeof(ipv4_map_ipv6));
+	    strcpy(ipv4_map_ipv6,src);
+
+	    memset(octet, NULL, sizeof(octet));
+	    memset(ipv4, NULL, sizeof(ipv4));
+	    memset(octet_1, NULL, sizeof(octet_1));
+	    memset(octet_2, NULL, sizeof(octet_2));
+	    memset(concat_octets, NULL, sizeof(concat_octets));
+
+	    ptr_src = strtok(ipv4_map_ipv6,"::");
+
+	    strcpy(ipv4,ptr_src);
+
+	    ptr_src = strtok(ipv4,".");
+
+	    while (ptr_src != '\0')
+	    {
+
+		sscanf( ptr_src,"%d", &octet[octet_index]);
+
+		 if(octet[octet_index++] > 255)
+		 {
+		    return 0; // Invalid IP Address
+		 }
+
+		ptr_src = strtok (NULL, ".");
+
+	    }// end of main while loop
+
+
+	    if(octet_index < 4 || octet_index > 4)
+	    {
+		return 0; // Invalid IP Address
+	    }
+
+
+	    octet_index = 0;
+
+            str.ip6[0] = str.ip6[1] = str.ip6[2] = str.ip6[3] = str.ip6[4] = str.ip6[5] = 0;
+
+	    for (int i=6 ; i <= 7; i++)
+	    {
+		if (i == 7)
+		{
+		    ++octet_index;
+		}
+
+		sprintf(octet_1, "%02x", octet[octet_index]);
+
+		sprintf(octet_2, "%02x", octet[++octet_index]);
+
+		strcpy(concat_octets,octet_1);
+
+		strcat(concat_octets,octet_2);
+
+		sscanf(concat_octets,"%x",(unsigned int *)&str.ip6[i]);
+
+		memset(octet_1, NULL, sizeof(octet_1));
+
+		memset(octet_2, NULL, sizeof(octet_2));
+
+		memset(concat_octets, NULL, sizeof(concat_octets));
+	    }
+
+	    return 1;
+    }//end of ipv4_inet_pton() function
+
+    //Function to retain the IPv4 address from IPv6 Data Structure
+    char * ipv4_inet_ntop(char *destination)
+    {
+
+	    memset(destination,NULL,sizeof(destination));
+
+	    snprintf( destination ,IPV6_BUFFER_LENGTH, "%03x:%03x:%03x:%03x:%03x:%03x:%03d.%03d.%03d.%03d" ,
+	    str.ip6[0],str.ip6[1],str.ip6[2],str.ip6[3],str.ip6[4],str.ip6[5],
+	    (((unsigned int )str.ip6[6]>>8) & 0xFF),
+	    ((unsigned int )str.ip6[6] & 0xFF),
+	    (((unsigned int )str.ip6[7]>>8) & 0xFF),
+	    ((unsigned int )str.ip6[7] & 0xFF));
+
+	    return destination;
+
+     }// end of ipv4_inet_ntop function
+
+
+    //Function to store the IPv6 address in IPv6 Data Structure
+    int ipv6_inet_pton(const char *src)
+    {
+        //Local variables
+        char ipv6[IPV6_BUFFER_LENGTH];
+        
+        memset(ipv6,NULL,IPV6_BUFFER_LENGTH);
+        
+        strcpy(ipv6,src);
+        
+        char ipv6_temp[IPV6_BUFFER_LENGTH], ipv6_temp1[IPV6_BUFFER_LENGTH], ipv6_temp2[IPV6_BUFFER_LENGTH];
+
+        memset(ipv6_temp,NULL,IPV6_BUFFER_LENGTH);
+
+        strcpy(ipv6_temp,ipv6);
+
+        memset(ipv6_temp1,NULL,IPV6_BUFFER_LENGTH);
+
+        strcpy(ipv6_temp1,ipv6);
+
+        memset(ipv6_temp2,NULL,IPV6_BUFFER_LENGTH);
+
+        strcpy(ipv6_temp2,ipv6);
+
+
+        static const char hex[] = "0123456789abcdef";
+        char temp[IPV6_BUFFER_LENGTH];
+        char *ptr_src ,*ptr_char, *ptr_src1;
+        const char *char_ptr_src;  // get the src char
+        int char_int = NULL, index_ip6 = 0 ,octet_count=0, not_colon = 0, colon =0, count_colon = 0;
+        char temp_first[IPV6_BUFFER_LENGTH],temp_end[IPV6_BUFFER_LENGTH];
+
+        memset(temp_first, NULL,IPV6_BUFFER_LENGTH);
+
+        memset(temp_end, NULL,IPV6_BUFFER_LENGTH);
+
+        ptr_src = ipv6;
+        //while loop check three consective colons
+         while (*ptr_src != '\0')
+         {
+
+            if (*ptr_src == ':' && *++ptr_src == ':' && *++ptr_src == ':')
+            {
+                return 0; // Invalid IP Address
+            }
+
+            ++ptr_src;
+          }
+
+        //while loop count the total number of octets
+        ptr_src = strtok (ipv6_temp2,":");
+
+
+        while (ptr_src != NULL)
+        {
+            octet_count++;
+
+            ptr_src = strtok (NULL, ":");
+        }
+
+        //Retrun zero if total number of octets are greater than 8
+        if(octet_count > 8)
+        {
+            return 0 ; // Invalid IP Address
+        }
+
+        int num_miss_octet =0, size =0; 
+
+	num_miss_octet = 8 - octet_count;
+        size = 2*num_miss_octet +1;
+        
+	char * zero_append = new char[size];
+
+        memset(zero_append,NULL,sizeof(zero_append));
+
+
+        ptr_src = ipv6_temp;
+
+        //while loop locate the "::" position (start,middle or end)
+        while(*ptr_src != '\0')
+        {
+            if(*ptr_src == ':' && *++ptr_src == ':')
+            {
+                if (*++ptr_src=='\0')
+                {
+                    colon =2;
+                }
+                else if (not_colon == 0)
+                {
+                    colon=1;
+                }
+                else
+                {
+                    colon=3;
+                }
+
+                count_colon++;
+
+                if(count_colon == 2)
+                {
+                    return 0; // Invalid IP Address. Ther must be single time double  colon '::'
+                }
+            }
+
+            ptr_src++;
+            not_colon++;
+        }// end of while loop
+
+        // if colon = 0 means the IPv6 Address string is in presffered form otherwise first it covert it into prefeered form
+        if(colon>0)
+        {
+            //zero padding format according to the '::' position
+            strcpy(zero_append,"");
+
+
+            for (int i= 0; i < num_miss_octet; i++)
+            {
+                if(colon==1) // start
+                {
+                    strcat(zero_append,"0:");
+                }
+                if(colon==2 || colon==3)  //middle or end colon =2 shows at end
+                {
+                    strcat(zero_append,":0");
+                }
+            }
+            if(colon==3)
+            {
+                strcat(zero_append,":");
+            }
+
+            ptr_src = temp_end;
+
+            if(colon==1 || colon==3)
+            {  //only for start and middle
+
+              ptr_src1 = strstr (ipv6_temp,"::");
+
+              ptr_src1 = ptr_src1+2;
+
+              while(*ptr_src1 != '\0')
+              {
+                *ptr_src++ = *ptr_src1++;
+
+                if(*ptr_src1 == '\0')
+                {
+                    *ptr_src ='\0';
+                }
+              }
+            }
+
+            //copy the input IPv6 string before and after '::'
+            ptr_src1 = strstr (ipv6_temp1,"::");
+
+            *ptr_src1 ='\0';
+
+
+            strcpy(temp_first,ipv6_temp1);
+
+            if(colon==2) // end
+            {
+                strcat(temp_first,zero_append);
+            }
+            else
+            {
+                strcat(temp_first,zero_append);
+
+                strcat(temp_first,temp_end);
+            }
+
+            memset(ipv6,NULL,IPV6_BUFFER_LENGTH);
+
+            strcpy(ipv6,temp_first);
+        }// end of main if statement
+
+
+
+        //while loop store each octet on ipv6 struture in decimal value of hexadecimal digits
+        ptr_char = temp;
+
+        ptr_src = strtok (ipv6,":");
+
+
+        while (ptr_src != NULL)
+        {
+                strcpy(temp, ptr_src);
+
+                ptr_char = temp;
+
+                int octet_length = strlen(ptr_char);
+
+                *(ptr_char + octet_length) = '\0';
+
+
+                while(*ptr_char != '\0')
+                {
+                    char_int = tolower(*ptr_char);
+
+                    char_ptr_src = strchr (hex, char_int);
+
+                    if(char_ptr_src == NULL)
+                    {
+                        return 0; // Invalid IP Address
+
+                    }
+
+                        *ptr_char = *char_ptr_src;
+                        ptr_char++;
+                }//end of inner while loop
+
+                ptr_char-= octet_length;
+
+
+                unsigned int  *ptr  =  (unsigned int *)&(str.ip6[index_ip6++]);
+
+                sscanf( ptr_char,"%x", ptr);
+
+
+                memset(temp,NULL,IPV6_BUFFER_LENGTH);
+
+
+                ptr_src = strtok (NULL, ":");
+        }// end of main while loop
+	
+	delete [] zero_append;
+
+        return 1;
+    }// end of Ipv6_Inet_pton function
+
+    //Function to retain the IPv6 address from IPv6 Data Structure
+    char* ipv6_inet_ntop(char *destination)
+    {
+        char temp[10];
+
+        memset(temp,NULL,sizeof(temp));
+
+        memset(destination,NULL,IPV6_BUFFER_LENGTH);
+        
+    
+        for (int i= 0; i <= 7; i++)
+        {
+            if(i==7)
+            {
+                sprintf(temp,"%04x",str.ip6[i]);
+
+                strcat(destination,temp);
+            }
+            else
+            {
+                sprintf(temp,"%04x:",str.ip6[i]);
+
+                strcat(destination,temp);
+            }
+
+            memset(temp,NULL,sizeof(temp));
+        }
+
+
+        return destination;
+    }// end of Ipv6_Inet_ntop function
+
+
+    public:
+
+    IPv6()
+    {
+        str.ip6[0] = str.ip6[1] = str.ip6[2] = str.ip6[3] = str.ip6[4] = str.ip6[5] = str.ip6[6] = str.ip6[7] = 0;    
+    }
+
+
+    void store_object(unsigned char *out)
+    {
+	memcpy(out, (unsigned char *)&str, sizeof(str));
+    }
+
+    void restore_object(const unsigned char * in)
+    {
+    	memcpy(&str, (struct ipv6_ds *)in,  sizeof(str));
+    } 
+
+    int inet_pton(const char *ip)
+    {
+         char * pch;
+
+         pch=strchr((char *)ip,'.');
+
+         if(pch == NULL)
+         {
+            return ipv6_inet_pton(ip);
+         }
+         else
+         {
+            return ipv4_inet_pton(ip);
+         }
+    }
+
+    char * inet_ntop(char *dest)
+    {
+        if (str.ip6[0]==0 && str.ip6[1]==0 && str.ip6[2]==0 && str.ip6[3]==0 && str.ip6[4]==0 && str.ip6[5]==0 && str.ip6[6]!=0)
+        {
+            return ipv4_inet_ntop(dest);
+        }
+        else
+        {
+            return ipv6_inet_ntop(dest);
+        }
+    }
+    
+    static const size_t LENGTH= 16;
+    static const size_t IPV6_DISPLAY_LENGTH= 39;
+    static const size_t IPV6_BUFFER_LENGTH= IPV6_DISPLAY_LENGTH+1;
+
+};  // endof class
+
+} /* namespace type */
+} /* namespace drizzled */
+
+

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-08-11 09:18:19 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-08-16 11:47:29 +0000
@@ -3976,6 +3976,8 @@
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
     return(DATA_FIXBINARY);
+  case DRIZZLE_TYPE_IPV6:
+   return(DATA_FIXBINARY);
   case DRIZZLE_TYPE_NULL:
     ut_error;
   }

=== added directory 'plugin/ipv6_function'
=== added file 'plugin/ipv6_function/ipv6_function.cc'
--- plugin/ipv6_function/ipv6_function.cc	1970-01-01 00:00:00 +0000
+++ plugin/ipv6_function/ipv6_function.cc	2011-08-16 11:47:29 +0000
@@ -0,0 +1,105 @@
+/*
+  Original copyright header listed below. This comes via rsync.
+  Any additional changes are provided via the same license as the original.
+
+  Copyright (C) 2011 Muhammad Umair
+
+*/
+/*
+ * Copyright (C) 1996-2001  Internet Software Consortium.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+ * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+ * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#include <config.h>
+
+#include <drizzled/error.h>
+#include <drizzled/charset.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <drizzled/plugin/function.h>
+
+#include <drizzled/type/ipv6.h>
+
+namespace plugin {
+namespace ipv6 {
+
+class Generate: public drizzled::Item_str_func
+{
+public:
+  Generate(): drizzled::Item_str_func() {}
+  void fix_length_and_dec()
+  {
+    max_length= (drizzled::type::IPv6::IPV6_BUFFER_LENGTH) * drizzled::system_charset_info->mbmaxlen;
+  }
+  const char *func_name() const{ return "ipv6"; }
+  drizzled::String *val_str(drizzled::String *);
+};
+
+
+drizzled::String *Generate::val_str(drizzled::String *str)
+{
+  drizzled::String _result;
+  drizzled::String *result= val_str(&_result);
+  drizzled::type::IPv6 ptr_address;
+
+  if (not ptr_address.inet_pton(result->c_str()))
+  {
+    drizzled::my_error(drizzled::ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+     str->length(0);
+
+    return str;
+  }
+
+  char *ipv6_string;
+  str->realloc(drizzled::type::IPv6::IPV6_BUFFER_LENGTH);
+  str->length(drizzled::type::IPv6::IPV6_BUFFER_LENGTH);
+  str->set_charset(drizzled::system_charset_info);
+  ipv6_string= (char *) str->ptr();
+
+  if (not ptr_address.inet_ntop(ipv6_string))
+  {
+    drizzled::my_error(drizzled::ER_INVALID_IPV6_VALUE, MYF(ME_FATALERROR));
+    str->length(0);
+
+    return str;
+  }
+  str->length(max_length);
+
+  return str;
+}
+
+} // namespace ipv6
+} // namespace plugin
+
+static int initialize(drizzled::module::Context &context)
+{
+  context.add(new drizzled::plugin::Create_function<plugin::ipv6::Generate>("ipv6"));
+
+  return 0;
+}
+
+DRIZZLE_DECLARE_PLUGIN
+{
+  DRIZZLE_VERSION_ID,
+  "ipv6",
+  "1.0",
+  "Muhammad Umair",
+  "IPV6() function",
+  drizzled::PLUGIN_LICENSE_GPL,
+  initialize, /* Plugin Init */
+  NULL,   /* depends */
+  NULL    /* config options */
+}
+DRIZZLE_DECLARE_PLUGIN_END;

=== added file 'plugin/ipv6_function/plugin.ini'
--- plugin/ipv6_function/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/ipv6_function/plugin.ini	2011-08-16 11:47:29 +0000
@@ -0,0 +1,9 @@
+[plugin]
+title=IPV6() plugin
+author=Muhammad Umair
+version=1.0
+license=PLUGIN_LICENSE_GPL
+description=IPV6() function plugin
+load_by_default=yes
+sources= ipv6_function.cc
+static=yes

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2011-08-10 16:48:48 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2011-08-16 11:47:29 +0000
@@ -509,6 +509,10 @@
         pos[6]= DRIZZLE_COLUMN_TYPE_VARCHAR;
         break;
 
+      case DRIZZLE_TYPE_IPV6:
+        pos[6]= DRIZZLE_COLUMN_TYPE_VARCHAR;
+        break;
+
       case DRIZZLE_TYPE_BOOLEAN:
         pos[6]= DRIZZLE_COLUMN_TYPE_TINY;
         break;

=== added directory 'tests/suite/ipv6_type'
=== added directory 'tests/suite/ipv6_type/r'
=== added file 'tests/suite/ipv6_type/r/alter_add_ipv6.result'
--- tests/suite/ipv6_type/r/alter_add_ipv6.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/alter_add_ipv6.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,44 @@
+CREATE TABLE t1 (A INT);
+SHOW CREATE TABLE t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `A` INT DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+ALTER TABLE t1 ADD COLUMN b IPV6 NOT NULL;
+SHOW CREATE TABLE t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `A` INT DEFAULT NULL,
+  `b` IPV6 NOT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+DROP TABLE t1;
+CREATE TABLE t1 (A INT);
+SHOW CREATE TABLE t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `A` INT DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+INSERT INTO t1 VALUES (1), (2), (3);
+SELECT COUNT(*) = 3 FROM t1;
+COUNT(*) = 3
+1
+ALTER TABLE t1 ADD COLUMN b IPV6 NOT NULL;
+ERROR HY000: Either a DEFAULt value or NULL NULL description is required for a new column if table is not empty
+SHOW CREATE TABLE t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `A` INT DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+ALTER TABLE t1 ADD COLUMN b IPV6 DEFAULT NULL;
+SELECT A,B FROM t1;
+A	B
+1	NULL
+2	NULL
+3	NULL
+SHOW CREATE TABLE t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `A` INT DEFAULT NULL,
+  `b` IPV6 DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/bad_conversions.result'
--- tests/suite/ipv6_type/r/bad_conversions.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/bad_conversions.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,24 @@
+CREATE TABLE t1 (a IPV6, PRIMARY KEY(a));
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` IPV6 NOT NULL,
+  PRIMARY KEY (`a`) USING BTREE
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+INSERT INTO t1 VALUES ("10FB::C:ABC:1F0C:44DA");
+SELECT a FROM t1;
+a
+10fb:0000:0000:0000:000c:0abc:1f0c:44da
+CREATE TABLE t2 (a REAL);
+INSERT INTO t2 SELECT a FROM t1 LIMIT 1;
+ERROR 01000: Data truncated for column 'a' at row 1
+SELECT a FROM t2;
+a
+CREATE TABLE t3 (a REAL);
+INSERT INTO t3 SELECT a FROM t1 LIMIT 1;
+ERROR 01000: Data truncated for column 'a' at row 1
+SELECT a FROM t3;
+a
+DROP TABLE t3;
+DROP TABLE t2;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/count.result'
--- tests/suite/ipv6_type/r/count.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/count.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,19 @@
+CREATE TABLE t1 (a IPV6);
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+0000:0000:0000:0000:0000:0000:0000:0001
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+SELECT count(a) FROM t1;
+count(a)
+4
+TRUNCATE t1;
+SELECT count(a) FROM t1;
+count(a)
+0
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/create.result'
--- tests/suite/ipv6_type/r/create.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/create.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,7 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` IPV6 DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/delete.result'
--- tests/suite/ipv6_type/r/delete.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/delete.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,23 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` IPV6 DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+0000:0000:0000:0000:0000:0000:0000:0001
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+DELETE FROM t1 WHERE a = "0000:0000:0000:0000:0000:0000:0000:0001";
+SELECT a FROM t1;
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/mixed.result'
--- tests/suite/ipv6_type/r/mixed.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/mixed.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,17 @@
+CREATE TABLE t1 (a IPV6);
+CREATE TABLE t2 (a VARCHAR(39));
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+a
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+INSERT INTO t2 SELECT a FROM t1;
+SELECT a FROM t2;
+a
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+TRUNCATE t1;
+INSERT INTO t1 SELECT a FROM t2;
+SELECT a FROM t2;
+a
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+DROP TABLE t2;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/order_by.result'
--- tests/suite/ipv6_type/r/order_by.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/order_by.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,23 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` IPV6 DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+0000:0000:0000:0000:0000:0000:0000:0001
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+SELECT a FROM t1 ORDER BY a;
+a
+0000:0000:0000:0000:0000:0000:0000:0001
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/primary_key.result'
--- tests/suite/ipv6_type/r/primary_key.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/primary_key.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,14 @@
+CREATE TABLE t1 (a IPV6, PRIMARY KEY(a));
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+ERROR 23000: Duplicate entry '2001:0db8:85a3:0000:0000:8a2e:0370:7334' for key 'PRIMARY'
+SELECT a FROM t1 ORDER BY a;
+a
+0000:0000:0000:0000:0000:0000:0000:0001
+000:000:000:000:000:000:192.168.100.010
+2001:0db8:85a3:0000:0000:8a2e:0370:7334
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/r/select_like_no_key.result'
--- tests/suite/ipv6_type/r/select_like_no_key.result	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/r/select_like_no_key.result	2011-08-16 11:47:29 +0000
@@ -0,0 +1,18 @@
+CREATE TABLE t1 (a IPV6);
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("FD01::1F");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("::1");
+SELECT a FROM t1;
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+fd01:0000:0000:0000:0000:0000:0000:001f
+000:000:000:000:000:000:192.168.100.010
+0000:0000:0000:0000:0000:0000:0000:0001
+SELECT a FROM t1 WHERE a = "0fe8:0000:0000:0000:0000:b3ff:fe1a:8329";
+a
+0fe8:0000:0000:0000:0000:b3ff:fe1a:8329
+SELECT a FROM t1 WHERE a LIKE "000:000:000:000:000:000:192.168.100.010";
+a
+000:000:000:000:000:000:192.168.100.010
+DROP TABLE t1;

=== added directory 'tests/suite/ipv6_type/t'
=== added file 'tests/suite/ipv6_type/t/alter_add_ipv6.test'
--- tests/suite/ipv6_type/t/alter_add_ipv6.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/alter_add_ipv6.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,17 @@
+CREATE TABLE t1 (A INT);
+SHOW CREATE TABLE t1;
+ALTER TABLE t1 ADD COLUMN b IPV6 NOT NULL;
+SHOW CREATE TABLE t1;
+DROP TABLE t1;
+
+CREATE TABLE t1 (A INT);
+SHOW CREATE TABLE t1;
+INSERT INTO t1 VALUES (1), (2), (3);
+SELECT COUNT(*) = 3 FROM t1;
+--error ER_INVALID_ALTER_TABLE_FOR_NOT_NULL
+ALTER TABLE t1 ADD COLUMN b IPV6 NOT NULL;
+SHOW CREATE TABLE t1;
+ALTER TABLE t1 ADD COLUMN b IPV6 DEFAULT NULL;
+SELECT A,B FROM t1;
+SHOW CREATE TABLE t1;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/bad_conversions.test'
--- tests/suite/ipv6_type/t/bad_conversions.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/bad_conversions.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,15 @@
+CREATE TABLE t1 (a IPV6, PRIMARY KEY(a));
+show create table t1;
+INSERT INTO t1 VALUES ("10FB::C:ABC:1F0C:44DA");
+SELECT a FROM t1;
+CREATE TABLE t2 (a REAL);
+--error ER_WARN_DATA_TRUNCATED
+INSERT INTO t2 SELECT a FROM t1 LIMIT 1;
+SELECT a FROM t2;
+CREATE TABLE t3 (a REAL);
+--error ER_WARN_DATA_TRUNCATED
+INSERT INTO t3 SELECT a FROM t1 LIMIT 1;
+SELECT a FROM t3;
+DROP TABLE t3;
+DROP TABLE t2;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/count.test'
--- tests/suite/ipv6_type/t/count.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/count.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,10 @@
+CREATE TABLE t1 (a IPV6);
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+SELECT count(a) FROM t1;
+TRUNCATE t1;
+SELECT count(a) FROM t1;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/create.test'
--- tests/suite/ipv6_type/t/create.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/create.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,3 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/delete.test'
--- tests/suite/ipv6_type/t/delete.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/delete.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,10 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+DELETE FROM t1 WHERE a = "0000:0000:0000:0000:0000:0000:0000:0001";
+SELECT a FROM t1;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/mixed.test'
--- tests/suite/ipv6_type/t/mixed.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/mixed.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,11 @@
+CREATE TABLE t1 (a IPV6);
+CREATE TABLE t2 (a VARCHAR(39));
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+INSERT INTO t2 SELECT a FROM t1;
+SELECT a FROM t2;
+TRUNCATE t1;
+INSERT INTO t1 SELECT a FROM t2;
+SELECT a FROM t2;
+DROP TABLE t2;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/order_by.test'
--- tests/suite/ipv6_type/t/order_by.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/order_by.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,9 @@
+CREATE TABLE t1 (a IPV6);
+show create table t1;
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1;
+SELECT a FROM t1 ORDER BY a;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/primary_key.test'
--- tests/suite/ipv6_type/t/primary_key.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/primary_key.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,9 @@
+CREATE TABLE t1 (a IPV6, PRIMARY KEY(a));
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("::1");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+--error ER_DUP_ENTRY
+INSERT INTO t1 VALUES ("2001:db8:85a3::8a2e:370:7334");
+SELECT a FROM t1 ORDER BY a;
+DROP TABLE t1;

=== added file 'tests/suite/ipv6_type/t/select_like_no_key.test'
--- tests/suite/ipv6_type/t/select_like_no_key.test	1970-01-01 00:00:00 +0000
+++ tests/suite/ipv6_type/t/select_like_no_key.test	2011-08-16 11:47:29 +0000
@@ -0,0 +1,9 @@
+CREATE TABLE t1 (a IPV6);
+INSERT INTO t1 VALUES ("fe8::b3ff:fe1a:8329");
+INSERT INTO t1 VALUES ("FD01::1F");
+INSERT INTO t1 VALUES ("::192.168.100.10");
+INSERT INTO t1 VALUES ("::1");
+SELECT a FROM t1;
+SELECT a FROM t1 WHERE a = "0fe8:0000:0000:0000:0000:b3ff:fe1a:8329";
+SELECT a FROM t1 WHERE a LIKE "000:000:000:000:000:000:192.168.100.010";
+DROP TABLE t1;

